@@ -1,9 +1,9 @@
 package Mail::Milter::Authentication::Handler::ARC;
 use strict;
 use warnings;
-use Mail::Milter::Authentication 2;
+use Mail::Milter::Authentication 2.20180510;
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20180318'; # VERSION
+our $VERSION = '2.20180510'; # VERSION
 # ABSTRACT: Authentication Milter Module for validation of ARC signatures
 use Data::Dumper;
 use English qw{ -no_match_vars };
@@ -114,6 +114,7 @@ sub eoh_callback {
         $self->set_object('arc', $arc, 1);
     };
     if ( my $error = $@ ) {
+        $self->handle_exception( $error );
         $self->log_error( 'ARC Setup Error ' . $error );
         $self->_check_error( $error );
         $self->metric_count( 'arc_total', { 'result' => 'error' } );
@@ -130,6 +131,7 @@ sub eoh_callback {
         );
     };
     if ( my $error = $@ ) {
+        $self->handle_exception( $error );
         $self->log_error( 'ARC Headers Error ' . $error );
         $self->_check_error( $error );
         $self->metric_count( 'arc_total', { 'result' => 'error' } );
@@ -167,6 +169,7 @@ sub body_callback {
             $arc->PRINT( $arc_chunk );
         };
         if ( my $error = $@ ) {
+            $self->handle_exception( $error );
             $self->log_error( 'ARC Body Error ' . $error );
             $self->_check_error( $error );
             $self->metric_count( 'arc_total', { 'result' => 'error' } );
@@ -223,6 +226,7 @@ sub eom_callback {
             # set using safe_set_value
             eval { $header_comment->set_value( $header_comment_text ); };
             if ( my $error = $@ ) {
+                $self->handle_exception( $error );
                 $header_comment->safe_set_value( $header_comment_text );
             }
             $header->add_child( $header_comment );
@@ -233,6 +237,7 @@ sub eom_callback {
         $self->{arc_result} = $arc_result;
     };
     if ( my $error = $@ ) {
+        $self->handle_exception( $error );
         $self->log_error( 'ARC EOM Error ' . $error );
         $self->_check_error( $error );
         $self->metric_count( 'arc_total', { 'result' => 'error' } );
@@ -399,6 +404,7 @@ sub addheader_callback {
     };
 
     if ( my $error = $@ ) {
+        $self->handle_exception( $error );
         $self->log_error( 'ARCSeal Error ' . $error );
         $self->metric_count( 'arcseal_total', { 'result' => 'error' } );
         return;
@@ -419,7 +425,7 @@ Mail::Milter::Authentication::Handler::ARC - Authentication Milter Module for va
 
 =head1 VERSION
 
-version 2.20180318
+version 2.20180510
 
 =head1 DESCRIPTION
 
